@@ -3,8 +3,9 @@ Main interface for docdb service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.docdb import (
+    from mypy_boto3_docdb import (
         Client,
         DBInstanceAvailableWaiter,
         DBInstanceDeletedWaiter,
@@ -15,7 +16,7 @@ Usage::
         DescribeEventsPaginator,
         DescribeOrderableDBInstanceOptionsPaginator,
         DocDBClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -31,8 +32,9 @@ Usage::
     describe_db_subnet_groups_paginator: DescribeDBSubnetGroupsPaginator = client.get_paginator("describe_db_subnet_groups")
     describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
     describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator("describe_orderable_db_instance_options")
+    ```
 """
-from mypy_boto3_docdb.client import DocDBClient as Client, DocDBClient
+from mypy_boto3_docdb.client import DocDBClient, DocDBClient as Client
 from mypy_boto3_docdb.paginator import (
     DescribeDBClustersPaginator,
     DescribeDBEngineVersionsPaginator,
