@@ -3,9 +3,11 @@ Main interface for docdb service type definitions.
 
 Usage::
 
-    from mypy_boto3.docdb.type_defs import AvailabilityZoneTypeDef
+    ```python
+    from mypy_boto3_docdb.type_defs import AvailabilityZoneTypeDef
 
     data: AvailabilityZoneTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
