@@ -3,8 +3,11 @@ Main interface for docdb service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.docdb import (
+
+    from mypy_boto3_docdb import DocDBClient
+    from mypy_boto3_docdb.waiter import (
         DBInstanceAvailableWaiter,
         DBInstanceDeletedWaiter,
     )
@@ -13,6 +16,7 @@ Usage::
 
     db_instance_available_waiter: DBInstanceAvailableWaiter = client.get_waiter("db_instance_available")
     db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import List, TYPE_CHECKING
@@ -25,7 +29,7 @@ __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
     """
 
     def wait(
@@ -37,13 +41,13 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
+        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
     """
 
     def wait(
@@ -55,5 +59,5 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
+        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
         """
